Module events

Module events 

Event hooks and observability for taskgraph-rs. Fully compatible with no_std.

Structs

ConsoleSubscriber
A simple log subscriber that prints to stdout (std only).

Enums

TaskEvent
Event types emitted during task lifecycle.

Traits

TaskSubscriber
Trait for observers that want to react to task events.