Event hooks and observability for taskgraph-rs.
Fully compatible with no_std.
Structs
- Console
Subscriber - A simple log subscriber that prints to stdout (std only).
Enums
- Task
Event - Event types emitted during task lifecycle.
Traits
- Task
Subscriber - Trait for observers that want to react to task events.